Module create_138

Module create_138 

Create Allocation command [microversion = 1.38]

Wraps invoking of the allocations with POST method

Structs

AllocationCommand
Create, update or delete allocations for multiple consumers in a single request. This allows a client to atomically set or swap allocations for multiple consumers as may be required during a migration or move type operation.