Module set_112

Module set_112 

Set Allocation command [microversion = 1.12]

Wraps invoking of the allocations/{consumer_uuid} with PUT method

Structs

AllocationCommand
Create or update one or more allocation records representing the consumption of one or more classes of resources from one or more resource providers by the consumer identified by {consumer_uuid}. If allocations already exist for this consumer, they are replaced.