Show AllocationCandidate command
Wraps invoking of the allocation_candidates with GET method
Structs
- Allocation
Candidate Command - Returns a dictionary representing a collection of allocation requests and
resource provider summaries. Each allocation request has information to
form a
PUT /allocations/{consumer_uuid}request to claim resources against a related set of resource providers. Additional parameters might be required, see Update allocations. As several allocation requests are available it’s necessary to select one. To make a decision, resource provider summaries are provided with the inventory/capacity information. For example, this information is used by nova-scheduler’s FilterScheduler to make decisions about on which compute host to build a server.