pub struct AllocationCandidateCommand { /* private fields */ }Expand description
Returns a dictionary representing a collection of allocation requests and
resource provider summaries. Each allocation request has information to
form a PUT /allocations/{consumer_uuid} request to claim resources
against a related set of resource providers. Additional parameters might be
required, see Update allocations. As several
allocation requests are available it’s necessary to select one. To make a
decision, resource provider summaries are provided with the
inventory/capacity information. For example, this information is used by
nova-scheduler’s FilterScheduler to make decisions about on which compute
host to build a server.
You can also find additional case studies of the request parameters in the Modeling with Provider Trees document.
Normal Response Codes: 200
Error response codes: badRequest(400)
Implementations
Sourceimpl AllocationCandidateCommand
impl AllocationCandidateCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action