Module create_134

Module create_134 

Create Reshaper command [microversion = 1.34]

Wraps invoking of the reshaper with POST method

Structs

ReshaperCommand
Atomically migrate resource provider inventories and associated allocations. This is used when some of the inventory needs to move from one resource provider to another, such as when a class of inventory moves from a parent provider to a new child provider.