Module set

Set Trait command

Wraps invoking of the resource_providers/{uuid}/traits with PUT method

Structs

TraitCommand
Associate traits with the resource provider identified by {uuid}. All the associated traits will be replaced by the traits specified in the request body.