Module get

Get Usage command

Wraps invoking of the resource_providers/{uuid}/usages with GET method

Structs

UsageCommand
Return a report of usage information for resources associated with the resource provider identified by {uuid}. The value is a dictionary of resource classes paired with the sum of the allocations of that resource class for this resource provider.