List Usages command
Wraps invoking of the usages with GET method
Structs
- Usages
Command - Return a report of usage information for resources associated with the project identified by project_id and user identified by user_id. The value is a dictionary of resource classes paired with the sum of the allocations of that resource class for provided parameters.